跳到主要内容

KeyIdMethod

搜索

枚举 KeyIdMethod 

#[non_exhaustive]
pub enum KeyIdMethod { Sha256, Sha384, Sha512, PreSpecified(Vec<u8>), }
展开描述

从公钥生成密钥标识符的方法.

密钥标识符应从公钥数据派生。RFC 7093 规定了三种实现方式: 分别使用 SHA256(方法 1)、SHA384(方法 2)或 SHA512(方法 3)。 在每种情况下,均取哈希值的前 160 位作为密钥标识符, 以匹配使用 SHA1(RFC 5280 中定义的遗留选项)时所产生输出的长度。

除 RFC 7093 规定的机制外,rcgen 还支持使用预先指定的密钥标识符, 这在与现有的 Certificate 协作时尤为便利。

变体 (Non-exhaustive)

This enum is marked as non-exhaustive
非穷尽枚举未来可能添加新的变体。因此,在对非穷尽枚举的变体进行模式匹配时,必须额外增加一个通配符分支以涵盖未来的新变体。


Sha256

RFC 7093 方法 1 —— SHA256 摘要的截断值。



Sha384

RFC 7093 方法 2 —— SHA384 摘要的截断值。



Sha512

RFC 7093 方法 3 —— SHA512 摘要的截断值。



PreSpecified(Vec<u8>)

预指定的标识符。完全使用给定值作为密钥标识符。

Trait 实现

Source

impl Clone for KeyIdMethod

Source

fn clone(&self) -> KeyIdMethod

返回值的副本。 更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for KeyIdMethod

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl Hash for KeyIdMethod

Source

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 更多信息
1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 更多信息
Source

impl PartialEq for KeyIdMethod

Source

fn eq(&self, other: &KeyIdMethod) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
Source

impl Eq for KeyIdMethod

Source

impl StructuralPartialEq for KeyIdMethod

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

获得所有权后的类型。
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。