跳到主要内容

CertifiedIssuer

搜索

结构体 CertifiedIssuer 

pub struct CertifiedIssuer<'a, S> { /* private fields */ }
展开描述

一个 Issuer 包装,同时包含颁发者的 Certificate

实现

Source

impl<'a, S: SigningKey> CertifiedIssuer<'a, S>

pub fn self_signed( params: CertificateParams, signing_key: S, ) -> Result<Self, Error>

使用给定参数与密钥创建一个新的颁发者,附带一份自签名证书。

pub fn signed_by( params: CertificateParams, signing_key: S, issuer: &Issuer<'_, impl SigningKey>, ) -> Result<Self, Error>

使用给定参数与密钥创建一个新的颁发者,并由指定的 issuer 签名。

pub fn pem(&self) -> String

获取该证书的 PEM 编码形式。

pub fn der(&self) -> &CertificateDer<'static>

获取该证书的 DER 编码形式。

另请参见 Certificate::der()

Methods from Deref<Target = Issuer<'a, S>>

pub fn key_usages(&self) -> &[KeyUsagePurpose]

此颁发者所允许的 key usage。

pub fn key(&self) -> &S

返回签名密钥的引用。

Trait 实现

Source

impl<'a, S> AsRef<Certificate> for CertifiedIssuer<'a, S>

Source

fn as_ref(&self) -> &Certificate

将此类型转换为输入类型的共享引用(通常自动推导)。
Source

impl<'a, S: Debug> Debug for CertifiedIssuer<'a, S>

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl<'a, S> Deref for CertifiedIssuer<'a, S>

Source

type Target = Issuer<'a, S>

解引用后得到的类型。
Source

fn deref(&self) -> &Self::Target

解引用此值。

自动 Trait 实现



impl<'a, S> Freeze for CertifiedIssuer<'a, S>
where S: Freeze,



impl<'a, S> RefUnwindSafe for CertifiedIssuer<'a, S>
where S: RefUnwindSafe,



impl<'a, S> Send for CertifiedIssuer<'a, S>
where S: Send,



impl<'a, S> Sync for CertifiedIssuer<'a, S>
where S: Sync,



impl<'a, S> Unpin for CertifiedIssuer<'a, S>
where S: Unpin,



impl<'a, S> UnsafeUnpin for CertifiedIssuer<'a, S>
where S: UnsafeUnpin,



impl<'a, S> UnwindSafe for CertifiedIssuer<'a, S>
where S: UnwindSafe,

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

Source

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。