跳到主要内容

CrlIssuingDistributionPoint

搜索

结构体 CrlIssuingDistributionPoint 

pub struct CrlIssuingDistributionPoint {
    pub distribution_point: CrlDistributionPoint,
    pub scope: Option<CrlScope>,
}
展开描述

一个证书吊销列表(CRL)颁发分发点,包含在 CRL 的 issuing distribution point extension 扩展中。

字段

distribution_point: CrlDistributionPoint

该 CRL 的分发点,包含可从中获取该 CRL 的 URI 序列。

scope: Option<CrlScope>

对 CRL 范围的可选描述。若省略,则该 CRL 可同时包含用户证书与 CA 证书。

Trait 实现

Source

impl Clone for CrlIssuingDistributionPoint

Source

fn clone(&self) -> CrlIssuingDistributionPoint

返回值的副本。 更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for CrlIssuingDistributionPoint

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl PartialEq for CrlIssuingDistributionPoint

Source

fn eq(&self, other: &CrlIssuingDistributionPoint) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
Source

impl Eq for CrlIssuingDistributionPoint

Source

impl StructuralPartialEq for CrlIssuingDistributionPoint

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

获得所有权后的类型。
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。