跳到主要内容

RevokedCertParams

搜索

结构体 RevokedCertParams 

pub struct RevokedCertParams {
    pub serial_number: SerialNumber,
    pub revocation_time: OffsetDateTime,
    pub reason_code: Option<RevocationReason>,
    pub invalidity_date: Option<OffsetDateTime>,
}
展开描述

用于描述包含在 CertificateRevocationList 中的已吊销证书的参数。

字段

serial_number: SerialNumber

标识已吊销证书的序列号。

revocation_time: OffsetDateTime

CA 处理该吊销的日期。

reason_code: Option<RevocationReason>

标识证书为何被吊销的可选原因代码。

invalidity_date: Option<OffsetDateTime>

可选字段,描述已知或怀疑私钥泄露、或证书以其他方式失效的日期。 This date may be earlier than the RevokedCertParams::revocation_time.

Trait 实现

Source

impl Clone for RevokedCertParams

Source

fn clone(&self) -> RevokedCertParams

返回值的副本。 更多信息
1.0.0 · Source

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 更多信息
Source

impl Debug for RevokedCertParams

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl PartialEq for RevokedCertParams

Source

fn eq(&self, other: &RevokedCertParams) -> bool

测试 selfother 值是否相等,供 == 运算符使用。
1.0.0 · Source

fn ne(&self, other: &Rhs) -> bool

测试 != 运算符。默认实现几乎总是够用,除非有非常充分的理由,否则不应被覆盖。
Source

impl Eq for RevokedCertParams

Source

impl StructuralPartialEq for RevokedCertParams

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> CloneToUninit for T
where T: Clone,

Source

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

That is, this conversion is whatever the implementation of From<T> for U 的实现方式。

Source

impl<T> ToOwned for T
where T: Clone,

Source

type Owned = T

获得所有权后的类型。
Source

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 更多信息
Source

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。